==> dl.php?src=linea21_1_7.zip: linea21/workshop/sup_com.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage workshop
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

if(isset($_POST['com_id']))	$com_id=$_POST['com_id'];
if(isset($_GET['com_id']))	$com_id=$_GET['com_id'];

if(isset($_POST['mes_id']))	$mes_id=$_POST['mes_id'];
if(isset($_GET['mes_id']))	$mes_id=$_GET['mes_id'];

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if ($l21auth->isWorkgroupOrganiser($l21auth->GetSessionElement('id'), $sql_object, $id)<>true && !$l21auth->isSuperAdmin())
ReloadIndex('admin');
////////////


$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_add_com=$rub_link."&amp;todo=add_com&amp;id=".$id."&amp;com_id=";
$link_list_com=$rub_link."&todo=list_com&id=".$id."";

if($com_id <> 0) $link_cancel=$rub_link."&amp;todo=det_com&amp;id=".$id."&amp;com_id=".$com_id;
else $link_cancel=$rub_link."&amp;todo=list_com&amp;id=".$id;

if(isset($_POST['annuler'])) {
  header("Location: ".$link_list_com);
}

$workshop_com_object= new workshop_com;

$req_com_mes = SQL_getOnetopicWorkcom($id, $mes_id, $mes_id);
$result_com_mes = $sql_object -> DBSelect($req_com_mes);
$com_root_subject=formatText($result_com_mes[0]['workcom_subject'], '2HTML');

if(isset($_POST['valider'])) {

  $result=$workshop_com_object->DeleteCom($id, $mes_id, $com_id, $sql_object);
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id."&com_id=".$com_id;
  if($com_id == $mes_id) $link_confirm.="&all=true";
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);

if(count($result)>1) exit();
$workshop_denomination=FormatText($result[0]['workshop_denomination'], '2HTML');

if ($com_id==0) {
  $navtitle=_t('workshop','add_com')." : ".$workshop_denomination;
  $titleh2=_t('workshop','name')." : ".$workshop_denomination;
}
else {
  $navtitle=_t('workshop','add_com_mes')." : ".$com_root_subject." (".$workshop_denomination.")";
  $titleh2=_t('workshop','com_name')." : ".$com_root_subject." ("._t('workshop','name')." :".$workshop_denomination.")";
}
?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','workshop')?></a></li>
	<li><span>
	<?php 
	if ($com_id==0) echo _t('workshop','sup_com')." : ". $com_root_subject;
	else  echo _t('workshop','sup_com_mes')." : ". $com_root_subject; ?>
	</span></li>
</ul>
</div>
<!--end barre haute -->
	<?php
	include_once(THEME_ADMIN_PATH."quickicons.php");
	?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php afflinkbar($todo,$id, $lang); ?> <?php 
if ($com_id==0) {

  echo "<h2>".$com_root_subject." ("._t('workshop','name')." : ".$workshop_denomination.")</h2>"; ?>
<form id="supcom" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<div class="info" id="truetransfert1">
		<?php echo _t('workshop','sup_com_warning'); ?>
	</div>
<div class="info" id="truetransfert2">
<?php
echo _t('workshop','sup_com_warning2');
}
else {
  echo "<h2>".$com_root_subject." ("._t('workshop','name')." : ".$workshop_denomination.")</h2>"; ?>
<form id="supcom" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<div class="info" id="truetransfert1"><i class="icon-trash"></i> <?php echo _t('workshop','sup_com_mes_warning'); 
} ?>
</div>
<div>
	<input name="id" type="hidden" value="<?php echo $id; ?>" />
	<input name="mes_id" type="hidden" value="<?php echo $mes_id; ?>" />
	<input name="com_id" type="hidden" value="<?php echo $com_id; ?>" />
	<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
	<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
	<?php echo cancel_button($link_cancel); ?>
	<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once(override($dir.'/help.php', THEME_ADMIN_PATH)); ?>
</div>

==> dl.php?src=linea21_2_0_0.zip: linea21/workshop/sup_com.php <==
<?php
/**
 * Workshop module - Delete forum topic page
 * 
 * Delete forum topic page
 * 
 * @package linea21\modules\workshop
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

if(isset($_POST['com_id']))	$com_id=$_POST['com_id'];
if(isset($_GET['com_id']))	$com_id=$_GET['com_id'];

if(isset($_POST['mes_id']))	$mes_id=$_POST['mes_id'];
if(isset($_GET['mes_id']))	$mes_id=$_GET['mes_id'];

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if ($l21auth->isWorkgroupOrganiser($l21auth->GetSessionElement('id'), $sql_object, $id)<>true && !$l21auth->isSuperAdmin())
ReloadIndex('admin');
////////////


$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_add_com=$rub_link."&amp;todo=add_com&amp;id=".$id."&amp;com_id=";
$link_list_com=$rub_link."&todo=list_com&id=".$id."";

if($com_id <> 0) $link_cancel=$rub_link."&amp;todo=det_com&amp;id=".$id."&amp;com_id=".$com_id;
else $link_cancel=$rub_link."&amp;todo=list_com&amp;id=".$id;

if(isset($_POST['annuler'])) {
  header("Location: ".$link_list_com);
}

$workshop_com_object= new workshop_com;

$req_com_mes = SQL_getOnetopicWorkcom($id, $mes_id, $mes_id);
$result_com_mes = $sql_object -> DBSelect($req_com_mes);

// Do record exists?
if(!isset($result_com_mes[0]['workcom_subject'])) redirect_to('@module_default');

$com_root_subject=formatText($result_com_mes[0]['workcom_subject'], '2HTML');

if(isset($_POST['valider'])) {

  $result=$workshop_com_object->DeleteCom($id, $mes_id, $com_id, $sql_object);
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id."&com_id=".$com_id;
  if($com_id == $mes_id) $link_confirm.="&all=true";
  if($result) header("Location: ".$link_confirm);
  else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);

// Do record exists?
if(!isset($result[0]['workshop_denomination'])) redirect_to('@module_default');

$workshop_denomination=FormatText($result[0]['workshop_denomination'], '2HTML');

if ($com_id==$mes_id) {
  $navtitle=_t('workshop','sup_com')." : ".$com_root_subject;
  $titleh2=_t('workshop','sup_com'). ' : ' . $com_root_subject;
}
else {
  $navtitle=_t('workshop','sup_com_mes')." : ".$com_root_subject;
  $titleh2=_t('workshop','sup_com_mes'). ' : ' . $com_root_subject;
}
?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','workshop')?></a></li>
	<li><span>
	<?php echo $navtitle; ?>
	</span></li>
</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>

<h2><?php echo  formatText($titleh2, '2HTML'); ?></h2>
<div class="subtitle" id="workshop-subtitle"><?php echo $workshop_denomination; ?></div>
<form id="supcom" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<div class="info"><i class="icon-trash"></i>
<?php 
if ($com_id == $mes_id) { 
	echo _t('workshop','sup_com_warning').'<br />'. _t('workshop','sup_com_warning2');
} else {
	echo _t('workshop','sup_com_mes_warning');
} ?>
</div>
<div>
	<input name="id" type="hidden" value="<?php echo $id; ?>" />
	<input name="mes_id" type="hidden" value="<?php echo $mes_id; ?>" />
	<input name="com_id" type="hidden" value="<?php echo $com_id; ?>" />
	<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
	<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
	<?php echo cancel_button($link_cancel); ?>
	<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
